==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/DeploymentTriggerPolicyFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class DeploymentTriggerPolicyFluentImpl<A extends io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent<A>{
  public DeploymentTriggerPolicyFluentImpl() {
  }
  public DeploymentTriggerPolicyFluentImpl(io.fabric8.openshift.api.model.DeploymentTriggerPolicy instance) {
    this.withImageChangeParams(instance.getImageChangeParams()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParamsBuilder imageChangeParams;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildImageChangeParams instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParams getImageChangeParams() {
    return this.imageChangeParams!=null?this.imageChangeParams.build():null;
  }
  public io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParams buildImageChangeParams() {
    return this.imageChangeParams!=null?this.imageChangeParams.build():null;
  }
  public A withImageChangeParams(io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParams imageChangeParams) {
    _visitables.get("imageChangeParams").remove(this.imageChangeParams);
    if (imageChangeParams!=null){ this.imageChangeParams= new io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParamsBuilder(imageChangeParams); _visitables.get("imageChangeParams").add(this.imageChangeParams);} return (A) this;
  }
  public java.lang.Boolean hasImageChangeParams() {
    return this.imageChangeParams != null;
  }
  public io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent.ImageChangeParamsNested<A> withNewImageChangeParams() {
    return new io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluentImpl.ImageChangeParamsNestedImpl();
  }
  public io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent.ImageChangeParamsNested<A> withNewImageChangeParamsLike(io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParams item) {
    return new io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluentImpl.ImageChangeParamsNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent.ImageChangeParamsNested<A> editImageChangeParams() {
    return withNewImageChangeParamsLike(getImageChangeParams());
  }
  public io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent.ImageChangeParamsNested<A> editOrNewImageChangeParams() {
    return withNewImageChangeParamsLike(getImageChangeParams() != null ? getImageChangeParams(): new io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParamsBuilder().build());
  }
  public io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent.ImageChangeParamsNested<A> editOrNewImageChangeParamsLike(io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParams item) {
    return withNewImageChangeParamsLike(getImageChangeParams() != null ? getImageChangeParams(): item);
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    DeploymentTriggerPolicyFluentImpl that = (DeploymentTriggerPolicyFluentImpl) o;
    if (imageChangeParams != null ? !imageChangeParams.equals(that.imageChangeParams) :that.imageChangeParams != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(imageChangeParams,  type,  additionalProperties,  super.hashCode());
  }
  public class ImageChangeParamsNestedImpl<N> extends io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParamsFluentImpl<io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent.ImageChangeParamsNested<N>> implements io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent.ImageChangeParamsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ImageChangeParamsNestedImpl(io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParams item) {
      this.builder = new io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParamsBuilder(this, item);
    }
    ImageChangeParamsNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParamsBuilder(this);
    }
    io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParamsBuilder builder;
    public N and() {
      return (N) DeploymentTriggerPolicyFluentImpl.this.withImageChangeParams(builder.build());
    }
    public N endImageChangeParams() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/DeploymentTriggerPolicyFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class DeploymentTriggerPolicyFluentImpl<A extends io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent<A>{
  public DeploymentTriggerPolicyFluentImpl() {
  }
  public DeploymentTriggerPolicyFluentImpl(io.fabric8.openshift.api.model.DeploymentTriggerPolicy instance) {
    this.withImageChangeParams(instance.getImageChangeParams()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParamsBuilder imageChangeParams;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildImageChangeParams instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParams getImageChangeParams() {
    return this.imageChangeParams!=null?this.imageChangeParams.build():null;
  }
  public io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParams buildImageChangeParams() {
    return this.imageChangeParams!=null?this.imageChangeParams.build():null;
  }
  public A withImageChangeParams(io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParams imageChangeParams) {
    _visitables.get("imageChangeParams").remove(this.imageChangeParams);
    if (imageChangeParams!=null){ this.imageChangeParams= new io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParamsBuilder(imageChangeParams); _visitables.get("imageChangeParams").add(this.imageChangeParams);} return (A) this;
  }
  public java.lang.Boolean hasImageChangeParams() {
    return this.imageChangeParams != null;
  }
  public io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent.ImageChangeParamsNested<A> withNewImageChangeParams() {
    return new io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluentImpl.ImageChangeParamsNestedImpl();
  }
  public io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent.ImageChangeParamsNested<A> withNewImageChangeParamsLike(io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParams item) {
    return new io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluentImpl.ImageChangeParamsNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent.ImageChangeParamsNested<A> editImageChangeParams() {
    return withNewImageChangeParamsLike(getImageChangeParams());
  }
  public io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent.ImageChangeParamsNested<A> editOrNewImageChangeParams() {
    return withNewImageChangeParamsLike(getImageChangeParams() != null ? getImageChangeParams(): new io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParamsBuilder().build());
  }
  public io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent.ImageChangeParamsNested<A> editOrNewImageChangeParamsLike(io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParams item) {
    return withNewImageChangeParamsLike(getImageChangeParams() != null ? getImageChangeParams(): item);
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    DeploymentTriggerPolicyFluentImpl that = (DeploymentTriggerPolicyFluentImpl) o;
    if (imageChangeParams != null ? !imageChangeParams.equals(that.imageChangeParams) :that.imageChangeParams != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(imageChangeParams,  type,  additionalProperties,  super.hashCode());
  }
  public class ImageChangeParamsNestedImpl<N> extends io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParamsFluentImpl<io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent.ImageChangeParamsNested<N>> implements io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent.ImageChangeParamsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ImageChangeParamsNestedImpl(io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParams item) {
      this.builder = new io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParamsBuilder(this, item);
    }
    ImageChangeParamsNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParamsBuilder(this);
    }
    io.fabric8.openshift.api.model.DeploymentTriggerImageChangeParamsBuilder builder;
    public N and() {
      return (N) DeploymentTriggerPolicyFluentImpl.this.withImageChangeParams(builder.build());
    }
    public N endImageChangeParams() {
      return and();
    }
    
  }
  
}
